@@ -1,5 +1,7 @@
 #!/bin/bash
 
+set -e
+
 INTERFACE=${1:-} #optional, if not specified configure all available interfaces
 ENI_FILE="/etc/network/interfaces"
 
@@ -14,13 +16,17 @@ else
     exit 1
 fi
 
-if [ "$CONF_TYPE" == "eni" ]; then
-    # Serialize runs so that we don't miss hot-add interfaces
-    FLOCKED=${FLOCKED:-}
-    if [ -z "$FLOCKED" ] ; then
-        FLOCKED=true exec flock -x $ENI_FILE $0
-    fi
-fi
+ARGS="$0 $@"
+
+function serialize_me() {
+  if [ "$CONF_TYPE" == "eni" ]; then
+      # Serialize runs so that we don't miss hot-add interfaces
+      FLOCKED=${FLOCKED:-}
+      if [ -z "$FLOCKED" ] ; then
+          FLOCKED=true exec flock -x $ENI_FILE $ARGS
+      fi
+  fi
+}
 
 function get_if_link() {
   cat /sys/class/net/${1}/carrier
@@ -29,6 +35,7 @@ function get_if_link() {
 function enable_interface() {
   local interface=$1
 
+  serialize_me
   if [ "$CONF_TYPE" == "eni" ]; then
       printf "auto $interface\niface $interface inet dhcp\n\n" >>$ENI_FILE
   elif [ "$CONF_TYPE" == "netscripts" ]; then
@@ -41,6 +48,7 @@ function enable_interface() {
 function disable_interface() {
   local interface=$1
 
+  serialize_me
   if [ "$CONF_TYPE" == "netscripts" ]; then
       local IFCFG_FILE="/etc/sysconfig/network-scripts/ifcfg-$interface"
       if [ -f "$IFCFG_FILE" ]; then
@@ -58,12 +66,11 @@ function config_exists() {
     if [ "$CONF_TYPE" == "netscripts" ]; then
         if [ -f "/etc/sysconfig/network-scripts/ifcfg-$interface" ]; then
             return 0
-        else
-            return 1
         fi
     else
-        return ifquery $interface >/dev/null 2>&1
+        ifquery $interface >/dev/null 2>&1 && return 0
     fi
+    return 1
 }
 
 function inspect_interface() {
